<div align="center">
<p>
    <img src="https://res.cloudinary.com/vdesmond/image/upload/c_thumb,w_800,g_face/attractors_y4tepz.gif" />
</p>
<h1>attractors</h1>

attractors is a package for simulation and visualization of strange attractors.
</div>

[![codecov](https://codecov.io/github/vdesmond/attractors/graph/badge.svg?token=91EPQN331H)](https://codecov.io/github/vdesmond/attractors)

## Installation

```bash
pip install attractors
```

From source:
```bash
git clone https://github.com/vdesmond/attractors
cd attractors
pip install .
```

## Dependencies
- python >= 3.11
- matplotlib>=3.10.0
- numba>=0.60.0

## Basic Usage


## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md) for instructions on how to contribute.

## License

Distributed under the terms of the [MIT license](LICENSE).


<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/vdesmond/attractors/workflows/CI/badge.svg
[actions-link]:             https://github.com/vdesmond/attractors/actions
[pypi-link]:                https://pypi.org/project/attractors/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/attractors
[pypi-version]:             https://img.shields.io/pypi/v/attractors
<!-- prettier-ignore-end -->
